/***************************************************************************
 *                                                                         *
 *  MAXIMUS-CBCS Source Code, Version 1.02                                 *
 *  Copyright 1989, 1990 by Scott J. Dudley.  All rights reserved.         *
 *                                                                         *
 *  Oracle, the Maximus external .BBS file viewer                          *
 *                                                                         *
 *  For complete details of the licensing restrictions, please refer to    *
 *  the licence agreement, which is published in its entirety in MAX.C     *
 *  and LICENCE.MAX.                                                       *
 *                                                                         *
 *  USE OF THIS FILE IS SUBJECT TO THE RESTRICTIONS CONTAINED IN THE       *
 *  MAXIMUS-CBCS LICENSING AGREEMENT.  IF YOU DO NOT FIND THE TEXT OF THIS *
 *  AGREEMENT IN ANY OF THE  AFOREMENTIONED FILES, OR IF YOU DO NOT HAVE   *
 *  THESE FILES, YOU SHOULD IMMEDIATELY CONTACT THE AUTHOR AT ONE OF THE   *
 *  ADDRESSES LISTED BELOW.  IN NO EVENT SHOULD YOU PROCEED TO USE THIS    *
 *  FILE WITHOUT HAVING ACCEPTED THE TERMS OF THE MAXIMUS-CBCS LICENSING   *
 *  AGREEMENT, OR SUCH OTHER AGREEMENT AS YOU ARE ABLE TO REACH WITH THE   *
 *  AUTHOR.                                                                *
 *                                                                         *
 *  You can contact the author at one of the address listed below:         *
 *                                                                         *
 *  Scott Dudley           FidoNet  1:249/106                              *
 *  777 Downing St.        IMEXnet  89:483/202                             *
 *  Kingston, Ont.         Internet f106.n249.z1.fidonet.org               *
 *  Canada - K7M 5N3       BBS      (613) 389-8315 - HST/14.4K, 24hrs      *
 *                                                                         *
 ***************************************************************************/

#define INITIALIZE_MSG

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <dos.h>
#include <ctype.h>
#include "prog.h"
#include "max.h"
#include "max_msg.h"

int unum=0;

static void pascal Proc_Arg(char *a);
static void pascal Oracle_Help(void);
static void pascal Oracle_More(void);

static char oracle_name[PATHLEN];

void pascal Oracle_Parse_Args(char *ctlname,int argc,char *argv[])
{
  int x;
  
  char env_args[PATHLEN],
       *s;

  Hello("ORACLE","External *.BBS Display File Viewer",VERSION,"1990");
  
  timeon=time(NULL);
  timeoff=timeon+(1440L*60L);

  strcpy(prmname,"Max.Prm");
  strcpy(firstname,"Joe");

  Blank_User(&usr);

  strcpy(usr.name,"Joe SysOp");
  strcpy(usr.city,"Anytown, Canada");
  strcpy(usr.realname,"Joe Schlabotney");
  strcpy(usr.phone,"(123)456-7890");
  strcpy(usr.pwd,"Mypass");
  strcpy(usr.ldate,"02 Jun 90 01:23:45");

  usr.priv=SYSOP;
  usr.times=20;
  usr.upld=250;
  usr.dnld=1000;
  usr.dnldl=100;
  usr.credit=1500;
  usr.debit=345;
  usr.ansi=1;
  
  *oracle_name='\0';
     
  if ((s=getenv("ORACLE")) != NULL)
  {
    strcpy(env_args,s);
    
    for (s=strtok(env_args," ");s && *s;s=strtok(NULL," "))
      Proc_Arg(s);
  }

  if (argc <= 1)
    Oracle_Help();
  
  for (x=1;x < argc;x++)
    Proc_Arg(argv[x]);
}

static void pascal Proc_Arg(char *a)
{
  int x;
  
  char *orig,
       *s;

  orig=a;
  
  if (*a=='-' || *a=='/')
  {
    a++;
    
    switch (tolower(*a))
    {
      case 'h':
        a++;
        
        switch (tolower(*a))
        {
          case 'n':
            usr.help=NOVICE;
            break;
            
          case 'r':
            usr.help=REGULAR;
            break;
            
          case 'e':
            usr.help=EXPERT;
            break;
            
          case 'h':
            usr.help=HOTFLASH;
            break;
            
          default:
            printf("Error!  Invalid help level specified: `%c'!\n",*a);
        }
        break;
        
      case 'i':
        usr.ibmchars=0;
        break;

      case 'k':             /* Set keys */
        for (s=a+1;*s;s++)
          if (*s >= '1' && *s <= '8')
            UserKeyOn(*s-'1');
        break;
        
      case 'm':
        dsp_set=TRUE;
        
        switch(tolower(a[1]))
        {
          case 'd':
            displaymode=VIDEO_dos;
            break;
            
          case 'f':
            displaymode=VIDEO_fast;
            break;
            
          case 'i':
            displaymode=VIDEO_ibm;
            break;
            
          default:
            printf("Error!  Invalid local video mode: `%c'!\n",a[1]);
        }
        break;

      case 'p':             /* Set .PRM name */
        strcpy(prmname,++a);

        if (! strchr(prmname,'.'))
          strcat(prmname,".Prm");
        break;

      case 'q':
        usr.bits |= BITS_hotkeys;
        break;
        
      case 's':
        a++;
        
        switch(tolower(*a))
        {
          case 'l':
            usr.len=atoi(++a);
            break;
            
          case 'w':
            usr.width=atoi(++a);
            break;
            
          default:
            printf("Error!  Invalid screen option specified: `%c'!\n",*a);
        }
        break;

      case 't':             /* TTY mode */
        usr.ansi=0;
        usr.avatar=0;
        break;
        
      case 'v':             /* Set priv level */
        a++;
          
        for (x=0;x < _PRIVS_NUM;x++)
          if (toupper(*a)==*_privs[x].name)
          {
            usr.priv=_privs[x].priv;
            break;
          }
          
        if (x==_PRIVS_NUM)
          printf("Error!  Unknown priv level: `%c'!\n",*a);
        break;

      default:
        printf("Error!  Invalid command-line argument: `%s'!\n\n",orig);
        /* fall-through */
        
      case '?':
        Oracle_Help();
    }
  }
  else if (*a=='?')
    Oracle_Help();
  else strcpy(oracle_name,a);
}



void Oracle()
{
  if (! *oracle_name)
  {
    Printf("\nError!  No filename specified to display!\n");
    exit(1);
  }

  if (Display_File(0,NULL,oracle_name)==-1)
  {
    Printf("Error!  Can't open .BBS file for display.\n");
    exit(1);
  }

  vbuf_flush();
}


static void pascal Oracle_Help(void)
{
  printf("Oracle is a utility which will allow the SysOp to view a Maximus .BBS file,\n");
  printf("exactly as Maximus itself would display it, without having to log on.\n\n");

  printf("Command-line format:\n\n");
  
  printf("    ORACLE <bbsfile> [[-x]...]\n\n");
  
  printf("`-x' can be any of the following switches:\n\n");
  
  printf("-hX  - Set the current help level to X, where X is either of `N' (novice), 'R'\n");
  printf("       (regular), `E' (expert), or `H' (hotflash).\n");
  printf("-i   - Disables high-bit IBM characters.\n");
  printf("-kX  - Set the user's keys to X. ie. Use `-k149' to set keys 1, 4 and 9.\n");
  printf("-mX  - Set the local video mode to X, where X is one of 'D' (DOS),\n");
  printf("       'F' (FAST), or 'I' (IBM).\n");
  printf("-pX  - Read the Maximus PRM info from X.  ie. -pMAX.PRM\n");
  printf("-q   - Enable quick hotkeys.\n");
  printf("-slX - Set the virtual screen length to X rows.\n");
  printf("-swX - Set the virtual screen width to X columns.\n");

  Oracle_More();

  printf("-t   - Forces TTY mode (no colour/cursor movement)\n");
  printf("-vX  - Set the current priv level to X, where X is the first letter of a priv\n");
  printf("       level.  ie. -vs for SysOp, -vl for Limited, etc.\n\n");
  
  printf("You may also alter the default for these switches, by setting the ORACLE\n");
  printf("environment variable.  For example, issue the command:\n\n");
  
  printf("    SET ORACLE=-pD:\\MAX\\MAX.PRM -vS\n\n");
  
  printf("to set the default .PRM name to D:\\MAX\\MAX.PRM, and to set the default priv\n");
  printf("level to SysOp.  (Note that environment variable settings can be overriden on\n");
  printf("the command line.)\n");
  
  exit(1);
}

static void pascal Oracle_More(void)
{
  printf("[More]");
  pgetch();
  printf("\r      \r");
}

void pascal Fix_MagnEt(void) {}
int pascal Display_Options(char *name,struct _msg *msg) {return 0;}
void pascal File_Locate(void) {*linebuf='\0';}
void pascal Msg_Checkmail(void) {}
int pascal ChatFindIndividual(int tid,char *username,char *status,int *avail) {return 0;}
int pascal Header_Message(int entry) {return 0;}
int pascal Header_File(int entry) {return 0;}
int pascal Header_Change(int entry) {return 0;}
int pascal Header_None(int entry) {return 0;}
int pascal Goodbye_Comment(void) {return 0;}
void pascal Who_Is_On(void) {}
void pascal Add_To_Chat_List(int tid) {}
int pascal Remove_From_Chat_List(int tid) {return 0;}
void pascal ChatCleanUp(void) {}
void pascal Calc_Timeoff(void) {}
void pascal User_Edit(void) {}
int pascal Last_Other(void) {return 0;}
void pascal Validate_Runtime_Settings(void) {}
void pascal Fix_Lastread(void) {}
void pascal Get_File_Description(char *filename,long fsize,char *dsc) {}
void pascal Add_Upload_Bytes(long fsize) {}
void pascal Add_To_Upload_Log(char *path,char *fname,long bytes) {}
void pascal Check_Filename(char *ulpath,char *fname) {}
int pascal IsValidMsgArea(struct _area *a,int areanum) {return 1;}
void pascal Initialize_Menu(struct _menu *menu) {}
void pascal Free_Menu(struct _menu *menu) {}
int pascal OptionOkay(struct _opt *opt,int run_opt,int *do_what) {return 1;}
void pascal Write_LastUser(void) {}
int pascal Read_Area(struct _area *area,int an) {return 0;}
void pascal ChatSetStatus(int avail,char *status) {}
void pascal ChatSaveStatus(struct _css *css) {}
void pascal ChatRestoreStatus(struct _css *css) {}
void pascal Check_For_Message(char *s1,char *s2) {}
void pascal Parse_Local(int ch) {}
void pascal Keyboard_Off(void) {}
void pascal Close_Chatlog(void) {}
void pascal Read_External_Log(int ctltype,char *parm,long starttime,int method) {}
void pascal Write_External_Ctlfile(int ctltype,char *parm,int method) {}
void pascal Write_Stats(struct _bbs_stats *bstats) {}
void pascal Zoquo(void) {}
int Highbit_Allowed(void) {return TRUE;}
void pascal Mdm_Flow(int state) {}
char pascal mdm_dump(char buffer) {return 0;}
int  cdecl mdm_printf(char *format,...) {return 0;}
void pascal List_Message_Areas(void) {}
void pascal List_File_Areas(void) {}
int pascal BbsRunOpt(int opt_num,char *arg) {return 0;}

void pascal PleaseRespond(void) {return;}
void pascal Time5Left(void) {return;}
void pascal TimeAlmostUp(void) {return;}
void pascal TimeLimit(void) {return;}
void pascal Lost_Carrier(void) {return;}
void pascal Add_Message_Date(struct _msg *msg) {return;}
int pascal Last_Msg_Overlay(void) {return 0;}
int pascal Last_File_Overlay(void) {return 0;}

#ifndef OS_2
void pascal mdm_fflush(void) {}
#endif



